# clippt

CLI slideshows in Python and Textual.

## Installation

```shell
uv tool install clippt
```

## Running

Usage: clippt [OPTIONS] SOURCE

Options:
  --disable-footer  Disable footer.
  -c, --continue    Continue from last slide.

## Configuration

TOML / JSON / YAML format, to be described

## Examples

Syntax highlighting in many languages:

```shell
uv run clippt examples/fibonacci/
```